#######################
PyDMScaleIndicator
#######################

.. autoclass:: pydm.widgets.scale.PyDMScaleIndicator
   :members:
   :show-inheritance:


.. note::
   See `QFrame Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QFrame.html>`_ for all inherited properties and methods.
